@@ -15,8 +15,10 @@ import pysam
 import numpy as np
 import matplotlib.pyplot as plt
 
+import longbow.utils.constants
 from ..utils import bam_utils
 from ..utils import plot_utils
+from ..utils import model as LongbowModel
 from ..utils.model import LibraryModel
 
 from ..segment import command as segment
@@ -51,7 +53,7 @@ click_log.basic_config(logger)
 @click.option(
     "-m",
     "--model",
-    default="mas15",
+    default=longbow.utils.constants.DEFAULT_MODEL,
     show_default=True,
     help="The model to use for annotation.  If the given value is a pre-configured model name, then that "
          "model will be used.  Otherwise, the given value will be treated as a file name and Longbow will attempt to "
@@ -64,8 +66,9 @@ click_log.basic_config(logger)
     required=False,
     is_flag=True,
     default=False,
-    help="Do splitting of reads based on splitter delimiters, rather than whole array structure. "
-    "This splitting will cause delimiter sequences to be repeated in each read they bound.",
+    help="DEPRECATED.  Do splitting of reads based on splitter delimiters, rather than whole array structure. "
+    "This splitting will cause delimiter sequences to be repeated in each read they bound.  "
+    "This is now the default setting, and this flag has been DEPRECATED.",
 )
 @click.argument("input-bam", default="-" if not sys.stdin.isatty() else None, type=click.File("rb"))
 def main(pbi, output_prefix, model, do_simple_splitting, input_bam):
@@ -84,16 +87,17 @@ def main(pbi, output_prefix, model, do_simple_splitting, input_bam):
 
     # Get our model:
     if LibraryModel.has_prebuilt_model(model):
-        logger.info(f"Using %s", LibraryModel.pre_configured_models[model]["description"])
-        model = LibraryModel.build_pre_configured_model(model)
+        lb_model = LibraryModel.build_pre_configured_model(model)
     else:
         logger.info(f"Loading model from json file: %s", model)
-        model = LibraryModel.from_json_file(model)
+        lb_model = LibraryModel.from_json_file(model)
+    logger.info(f"Using %s: %s", model, lb_model.description)
+    model = lb_model
 
     if do_simple_splitting:
-        logger.info("Splitting algorithm: Simple Splitting")
-    else:
-        logger.info("Splitting algorithm: Bounded Region")
+        logger.warning("Simple splitting is now the default.  \"-s\" / \"--do-simple-splitting\" is now DEPRECATED.")
+    do_simple_splitting = True
+    logger.info("Using simple splitting mode.")
 
     # Prepare our delimiters for segmentation below:
     delimiters = segment.create_simple_delimiters(model)
@@ -149,7 +153,7 @@ def main(pbi, output_prefix, model, do_simple_splitting, input_bam):
                 _, segments = get_segments(read)
             except KeyError:
                 logger.error(f"Input bam file does not contain longbow segmented reads!  "
-                             f"No {bam_utils.SEGMENTS_TAG} tag detected on read {read.query_name} !")
+                             f"No {longbow.utils.constants.SEGMENTS_TAG} tag detected on read {read.query_name} !")
                 sys.exit(1)
 
             # Get the list of MAS-seq adapters in the segments and adjust for missing first adapters:
@@ -159,7 +163,7 @@ def main(pbi, output_prefix, model, do_simple_splitting, input_bam):
                     len(read_mas_seq_adapters) > 1 and \
                     read_mas_seq_adapters[0] == model.array_element_structure[1][0]:
                 read_mas_seq_adapters.insert(0, model.array_element_structure[0][0])
-            # NOTE: here model.array_element_structure[0][1] corresponds to the "10x_Adapter"
+            # NOTE: here model.array_element_structure[0][1] corresponds to "VENUS"
             #       that we use as our second segment in each array element.
 
             # Segment the array into segments using our actual segmentation algorithm so we have accurate counts:
@@ -197,7 +201,7 @@ def main(pbi, output_prefix, model, do_simple_splitting, input_bam):
             array_lengths.append(array_len)
 
             # Adjust names for segmented direction:
-            if read.get_tag(bam_utils.SEGMENTS_RC_TAG) == 1:
+            if read.get_tag(longbow.utils.constants.SEGMENTS_RC_TAG) == 1:
                 read_mas_seq_adapters = [a + rc_decorator for a in read_mas_seq_adapters]
 
             # Add our tally for our heatmap:
